@@ -5,14 +5,14 @@ use utf8;
 # Subroutines shared by the "adduser" and "deluser" utilities.
 #
 # Copyright (C) 2000-2004 Roland Bauerschmidt <rb@debian.org>
-#               2005-2025 Marc Haber <mh+debian-packages@zugschlus.de>
-#               2023 Guillem Jover <guillem@debian.org>
-#               2021-2022 Jason Franklin <jason@oneway.dev>
-#               2022 Matt Barry <matt@hazelmollusk.org>
+#               2004-2025 Marc Haber <mh+debian-packages@zugschlus.de>
+#               2005-2009 Joerg Hoh <joerg@joerghoh.de>
+#               2006-2008 Stephen Gran <sgran@debian.org>
 #               2016 Nis Martensen <nis.martensen@web.de>
 #               2016 Afif Elghraoui <afif@debian.org>
-#               2005-2009 Joerg Hoh <joerg@joerghoh.de>
-#               2008 Stephen Gran <sgran@debian.org>
+#               2021-2022 Jason Franklin <jason@oneway.dev>
+#               2022 Matt Barry <matt@hazelmollusk.org>
+#               2023 Guillem Jover <guillem@debian.org>
 #
 # Someo of the subroutines here are adopted from Debian's
 # original "adduser" program.
@@ -82,8 +82,8 @@ my $lockfile_path = '/run/adduser';
 use constant {
     filenamere => qr/[-_\.+!\$%&()\]\[;0-9a-zA-Z]+/,
     simplefilenamere => qr/[-_\.0-9a-zA-Z]+/,
-    pathre => qr/[-\p{Graph}_\.+!\$%&()\]\[;0-9a-zA-Z\/{}>*'@]+/,
-    simplepathre => qr/[-_\.0-9a-zA-Z\/]+/,
+    pathre => qr/[- \p{Graph}_\.+!\$%&()\]\[;0-9a-zA-Z\/{}>*'@]+/,
+    simplepathre => qr/[-_\$\.0-9a-zA-Z\/]+/,
     commentre => qr/["-_\.+!\$%&()\]\[;0-9a-zA-Z\/ ]*/,
     numberre => qr/[0-9]+/,
     namere => qr/^([^-+~:,\s\/][^:,\s\/]*)$/aa,
@@ -268,7 +268,7 @@ sub read_pool {
                 $comment = sanitize_string($comment, commentre);
             }
             if( defined $home ) {
-                $home = sanitize_string($home, pathre);
+                $home = sanitize_string($home, simplepathre);
             }
             if( defined $shell ) {
                 $shell = sanitize_string($shell, simplepathre);
@@ -490,7 +490,7 @@ sub preseed_config {
 
     # Read the configuration files
     foreach( @$conflistref ) {
-        my $configfile = sanitize_string($_, pathre);
+        my $configfile = sanitize_string($_, simplepathre);
         log_debug( "read configuration file %s\n", $configfile );
         read_config($configfile ,$configref);
     }
